@@ -108,9 +108,9 @@ device_id = lib.open_device(open_name)
 print("Device id: " + repr(device_id))
 
 if set_profile_8MT173_25_MEn1(lib, device_id) == Result.Ok:
-    print("Download profile has been successfully completed.")
+    print("The settings profile was successfully applied")
 else:
-    print("The profile was loaded with errors.")
+    print("The profile was loaded with errors")
 
 print("\nClosing")
 
