@@ -1,5 +1,5 @@
-#ifndef __8MID12_1_H
-#define __8MID12_1_H
+#ifndef __8MID20_12_H
+#define __8MID20_12_H
 
 #include <string.h>
 
@@ -10,18 +10,18 @@
 #endif
 
 
-#define 8MID12_1_H_BUILDER_VERSION_MAJOR  0
-#define 8MID12_1_H_BUILDER_VERSION_MINOR  9
-#define 8MID12_1_H_BUILDER_VERSION_BUGFIX 16
-#define 8MID12_1_H_BUILDER_VERSION_SUFFIX ""
-#define 8MID12_1_H_BUILDER_VERSION        "0.9.16"
+#define 8MID20_12_H_BUILDER_VERSION_MAJOR  0
+#define 8MID20_12_H_BUILDER_VERSION_MINOR  9
+#define 8MID20_12_H_BUILDER_VERSION_BUGFIX 16
+#define 8MID20_12_H_BUILDER_VERSION_SUFFIX ""
+#define 8MID20_12_H_BUILDER_VERSION        "0.9.16"
 
 
 #if defined(_MSC_VER)
 #define inline __inline
 #endif
 
-static inline result_t set_profile_8MID12_1_H(device_t id)
+static inline result_t set_profile_8MID20_12_H(device_t id)
 {
   result_t worst_result = result_ok;
   result_t result = result_ok;
@@ -155,9 +155,9 @@ static inline result_t set_profile_8MID12_1_H(device_t id)
   memset((void*)&edges_settings, 0, sizeof(edges_settings_t));
   edges_settings.BorderFlags = BORDER_STOP_RIGHT | BORDER_STOP_LEFT;
   edges_settings.EnderFlags = ENDER_SW2_ACTIVE_LOW | ENDER_SW1_ACTIVE_LOW | ENDER_SWAP;
-  edges_settings.LeftBorder = -971;
+  edges_settings.LeftBorder = -970;
   edges_settings.uLeftBorder = 0;
-  edges_settings.RightBorder = 910;
+  edges_settings.RightBorder = 923;
   edges_settings.uRightBorder = 0;
   result = set_edges_settings(id, &edges_settings);
 
@@ -411,9 +411,9 @@ static inline result_t set_profile_8MID12_1_H(device_t id)
 
   stage_information_t stage_information;
   memset((void*)&stage_information, 0, sizeof(stage_information_t));
-  const int8_t stage_information_Manufacturer_temp[16] = {83, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+  const int8_t stage_information_Manufacturer_temp[16] = {0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(stage_information.Manufacturer, stage_information_Manufacturer_temp, sizeof(int8_t) * 16);
-  const int8_t stage_information_PartNumber_temp[24] = {56, 77, 73, 68, 49, 50, 45, 49, 45, 72, 0, 0, 55, 0, 53, 0, 0, 52, 48, 68, 45, 69, 65, 83};
+  const int8_t stage_information_PartNumber_temp[24] = {56, 77, 73, 68, 50, 48, 45, 49, 46, 50, 45, 72, 0, 0, 53, 0, 0, 52, 48, 68, 45, 69, 65, 83};
   memcpy(stage_information.PartNumber, stage_information_PartNumber_temp, sizeof(int8_t) * 24);
   result = set_stage_information(id, &stage_information);
 
@@ -428,12 +428,12 @@ static inline result_t set_profile_8MID12_1_H(device_t id)
   stage_settings_t stage_settings;
   memset((void*)&stage_settings, 0, sizeof(stage_settings_t));
   stage_settings.LeadScrewPitch = 0.25;
-  const int8_t stage_settings_Units_temp[8] = {109, 109, 0, 114, 101, 101, 0, 0};
+  const int8_t stage_settings_Units_temp[8] = {0, 109, 0, 114, 101, 101, 0, 0};
   memcpy(stage_settings.Units, stage_settings_Units_temp, sizeof(int8_t) * 8);
   stage_settings.MaxSpeed = 0;
-  stage_settings.TravelRange = 11;
-  stage_settings.SupplyVoltageMin = 5;
-  stage_settings.SupplyVoltageMax = 12;
+  stage_settings.TravelRange = 18.799999237060547;
+  stage_settings.SupplyVoltageMin = 0;
+  stage_settings.SupplyVoltageMax = 0;
   stage_settings.MaxCurrentConsumption = 0;
   stage_settings.HorizontalLoadCapacity = 0;
   stage_settings.VerticalLoadCapacity = 0;
@@ -583,8 +583,8 @@ static inline result_t set_profile_8MID12_1_H(device_t id)
 
   gear_settings_t gear_settings;
   memset((void*)&gear_settings, 0, sizeof(gear_settings_t));
-  gear_settings.ReductionIn = 9;
-  gear_settings.ReductionOut = 4;
+  gear_settings.ReductionIn = 53;
+  gear_settings.ReductionOut = 40;
   gear_settings.RatedInputTorque = 0;
   gear_settings.RatedInputSpeed = 0;
   gear_settings.MaxOutputBacklash = 0;
