@@ -1,5 +1,5 @@
-#ifndef __8MT167_100
-#define __8MT167_100
+#ifndef __8MT60_200
+#define __8MT60_200
 
 #include <string.h>
 
@@ -10,18 +10,18 @@
 #endif
 
 
-#define 8MT167_100_BUILDER_VERSION_MAJOR  0
-#define 8MT167_100_BUILDER_VERSION_MINOR  9
-#define 8MT167_100_BUILDER_VERSION_BUGFIX 16
-#define 8MT167_100_BUILDER_VERSION_SUFFIX ""
-#define 8MT167_100_BUILDER_VERSION        "0.9.16"
+#define 8MT60_200_BUILDER_VERSION_MAJOR  0
+#define 8MT60_200_BUILDER_VERSION_MINOR  9
+#define 8MT60_200_BUILDER_VERSION_BUGFIX 16
+#define 8MT60_200_BUILDER_VERSION_SUFFIX ""
+#define 8MT60_200_BUILDER_VERSION        "0.9.16"
 
 
 #if defined(_MSC_VER)
 #define inline __inline
 #endif
 
-static inline result_t set_profile_8MT167_100(device_t id)
+static inline result_t set_profile_8MT60_200(device_t id)
 {
   result_t worst_result = result_ok;
   result_t result = result_ok;
@@ -49,7 +49,7 @@ static inline result_t set_profile_8MT167_100(device_t id)
   home_settings.SlowHome = 500;
   home_settings.uSlowHome = 0;
   home_settings.HomeDelta = 500;
-  home_settings.uHomeDelta = 0;
+  home_settings.uHomeDelta = 200;
   home_settings.HomeFlags = HOME_USE_FAST | HOME_STOP_SECOND_REV | HOME_STOP_FIRST_BITS | HOME_DIR_SECOND;
   result = set_home_settings(id, &home_settings);
 
@@ -65,9 +65,9 @@ static inline result_t set_profile_8MT167_100(device_t id)
   memset((void*)&move_settings, 0, sizeof(move_settings_t));
   move_settings.Speed = 1000;
   move_settings.uSpeed = 0;
-  move_settings.Accel = 2000;
-  move_settings.Decel = 4000;
-  move_settings.AntiplaySpeed = 1000;
+  move_settings.Accel = 1000;
+  move_settings.Decel = 2000;
+  move_settings.AntiplaySpeed = 50;
   move_settings.uAntiplaySpeed = 0;
   move_settings.MoveFlags = 0;
   result = set_move_settings(id, &move_settings);
@@ -82,12 +82,12 @@ static inline result_t set_profile_8MT167_100(device_t id)
 
   engine_settings_t engine_settings;
   memset((void*)&engine_settings, 0, sizeof(engine_settings_t));
-  engine_settings.NomVoltage = 1;
+  engine_settings.NomVoltage = 1200;
   engine_settings.NomCurrent = 1200;
-  engine_settings.NomSpeed = 5000;
+  engine_settings.NomSpeed = 4000;
   engine_settings.uNomSpeed = 0;
   engine_settings.EngineFlags = ENGINE_LIMIT_RPM | ENGINE_ACCEL_ON | ENGINE_REVERSE;
-  engine_settings.Antiplay = 575;
+  engine_settings.Antiplay = 50;
   engine_settings.MicrostepMode = MICROSTEP_MODE_FRAC_256;
   engine_settings.StepsPerRev = 200;
   result = set_engine_settings(id, &engine_settings);
@@ -135,7 +135,7 @@ static inline result_t set_profile_8MT167_100(device_t id)
   memset((void*)&secure_settings, 0, sizeof(secure_settings_t));
   secure_settings.LowUpwrOff = 800;
   secure_settings.CriticalIpwr = 4000;
-  secure_settings.CriticalUpwr = 5500;
+  secure_settings.CriticalUpwr = 5000;
   secure_settings.CriticalT = 800;
   secure_settings.CriticalIusb = 450;
   secure_settings.CriticalUusb = 520;
@@ -155,9 +155,9 @@ static inline result_t set_profile_8MT167_100(device_t id)
   memset((void*)&edges_settings, 0, sizeof(edges_settings_t));
   edges_settings.BorderFlags = BORDER_STOP_RIGHT | BORDER_STOP_LEFT;
   edges_settings.EnderFlags = ENDER_SW2_ACTIVE_LOW | ENDER_SW1_ACTIVE_LOW | ENDER_SWAP;
-  edges_settings.LeftBorder = 2000;
+  edges_settings.LeftBorder = 1500;
   edges_settings.uLeftBorder = 0;
-  edges_settings.RightBorder = 97000;
+  edges_settings.RightBorder = 77500;
   edges_settings.uRightBorder = 0;
   result = set_edges_settings(id, &edges_settings);
 
@@ -413,7 +413,7 @@ static inline result_t set_profile_8MT167_100(device_t id)
   memset((void*)&stage_information, 0, sizeof(stage_information_t));
   const int8_t stage_information_Manufacturer_temp[16] = {83, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(stage_information.Manufacturer, stage_information_Manufacturer_temp, sizeof(int8_t) * 16);
-  const int8_t stage_information_PartNumber_temp[24] = {56, 77, 84, 49, 54, 55, 45, 49, 48, 48, 0, 50, 56, 0, 0, 0, 48, 0, 48, 0, 0, 69, 65, 83};
+  const int8_t stage_information_PartNumber_temp[24] = {56, 77, 84, 54, 48, 45, 50, 48, 48, 0, 66, 83, 49, 0, 69, 110, 49, 0, 0, 0, 0, 69, 65, 83};
   memcpy(stage_information.PartNumber, stage_information_PartNumber_temp, sizeof(int8_t) * 24);
   result = set_stage_information(id, &stage_information);
 
@@ -430,13 +430,13 @@ static inline result_t set_profile_8MT167_100(device_t id)
   stage_settings.LeadScrewPitch = 0.5;
   const int8_t stage_settings_Units_temp[8] = {109, 109, 0, 114, 101, 101, 0, 0};
   memcpy(stage_settings.Units, stage_settings_Units_temp, sizeof(int8_t) * 8);
-  stage_settings.MaxSpeed = 5;
-  stage_settings.TravelRange = 100;
+  stage_settings.MaxSpeed = 10;
+  stage_settings.TravelRange = 200;
   stage_settings.SupplyVoltageMin = 12;
   stage_settings.SupplyVoltageMax = 36;
   stage_settings.MaxCurrentConsumption = 0;
-  stage_settings.HorizontalLoadCapacity = 30;
-  stage_settings.VerticalLoadCapacity = 7;
+  stage_settings.HorizontalLoadCapacity = 8;
+  stage_settings.VerticalLoadCapacity = 3;
   result = set_stage_settings(id, &stage_settings);
 
   if (result != result_ok)
@@ -449,7 +449,7 @@ static inline result_t set_profile_8MT167_100(device_t id)
 
   motor_information_t motor_information;
   memset((void*)&motor_information, 0, sizeof(motor_information_t));
-  const int8_t motor_information_Manufacturer_temp[16] = {0, 111, 116, 105, 111, 110, 32, 67, 111, 110, 116, 114, 111, 108, 32, 80};
+  const int8_t motor_information_Manufacturer_temp[16] = {77, 111, 116, 105, 111, 110, 32, 67, 111, 110, 116, 114, 111, 108, 32, 80};
   memcpy(motor_information.Manufacturer, motor_information_Manufacturer_temp, sizeof(int8_t) * 16);
   const int8_t motor_information_PartNumber_temp[24] = {0, 67, 45, 105, 45, 52, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
   memcpy(motor_information.PartNumber, motor_information_PartNumber_temp, sizeof(int8_t) * 24);
@@ -583,10 +583,10 @@ static inline result_t set_profile_8MT167_100(device_t id)
 
   gear_settings_t gear_settings;
   memset((void*)&gear_settings, 0, sizeof(gear_settings_t));
-  gear_settings.ReductionIn = 5;
-  gear_settings.ReductionOut = 2;
+  gear_settings.ReductionIn = 0;
+  gear_settings.ReductionOut = 0;
   gear_settings.RatedInputTorque = 0;
-  gear_settings.RatedInputSpeed = 1500;
+  gear_settings.RatedInputSpeed = 0;
   gear_settings.MaxOutputBacklash = 0;
   gear_settings.InputInertia = 0;
   gear_settings.Efficiency = 0;
@@ -613,7 +613,7 @@ static inline result_t set_profile_8MT167_100(device_t id)
   accessories_settings.TSMin = 0;
   accessories_settings.TSMax = 0;
   accessories_settings.TSGrad = 0;
-  accessories_settings.TSSettings = TS_TYPE_THERMOCOUPLE | TS_TYPE_UNKNOWN;
+  accessories_settings.TSSettings = TS_TYPE_UNKNOWN;
   accessories_settings.LimitSwitchesSettings = 0;
   result = set_accessories_settings(id, &accessories_settings);
 
